use flare::transform_editor::TransformEditor;
use flare_shader::Coefs;
use log::info;

struct TransformEditorApp {
    transform_editor: TransformEditor,
}

impl TransformEditorApp {
    fn new() -> Self {
        Self {
            transform_editor: TransformEditor::new()
        }
    }
}

impl eframe::App for TransformEditorApp {
    fn update(&mut self, ctx: &egui::Context, _frame: &mut eframe::Frame) {
        egui::TopBottomPanel::top("top_panel").show(ctx, |ui| {
            egui::menu::bar(ui, |ui| {
                ui.menu_button("File", |ui| {
                    if ui.button("Quit").clicked() {
                        ctx.send_viewport_cmd(egui::ViewportCommand::Close);
                    }
                });
                if ui.button("Add Transform").clicked() {
                    self.transform_editor.add_transform()
                }
            })
        });

        egui::CentralPanel::default().show(ctx, |ui| {
            self.transform_editor.ui(ctx, ui)
        });
    }
}

fn main() -> eframe::Result {
    std::env::set_var("RUST_LOG", "info");
    env_logger::init();
    info!("WTF");

    let initial_dimensions = egui::vec2(800., 600.);
    let mut wgpu_options = egui_wgpu::WgpuConfiguration::default();
    wgpu_options.present_mode = wgpu::PresentMode::Immediate;
    wgpu_options.desired_maximum_frame_latency = Some(1);
    let native_options = eframe::NativeOptions {
        viewport: egui::ViewportBuilder::default().with_inner_size(initial_dimensions),
        wgpu_options,
        renderer: eframe::Renderer::Wgpu,
        vsync: false,
        ..Default::default()
    };

    puffin::set_scopes_on(true);
    match puffin_http::Server::new("localhost:8585") {
        Ok(server) => {
            info!("Server open");
            std::mem::forget(server);
        }
        _ => {}
    }
    // std::mem::forget(puffin_http::Server::new("127.0.0.1:8585").expect("Unable to start server"));

    eframe::run_native(
        "transform_editor",
        native_options,
        Box::new(|cc| {
            Ok(Box::new(TransformEditorApp::new()))
        }),
    )
}